@@ -31,10 +31,13 @@ from __future__ import annotations
 import logging
 import platform
 import typing as t
+import warnings
 from importlib.util import find_spec
 
 import analytix
 
+_log = logging.getLogger(__name__)
+
 BANNER = r"""
 {r}            {o}             {y}            {g}88  {b}             {i}         {v}88
 {r}            {o}             {y}            {g}88  {b}             {i}  ,d     {v}""
@@ -120,3 +123,10 @@ def setup_logging(level: int = logging.INFO) -> logging.StreamHandler[t.TextIO]:
         handlers=[handler],
     )
     return handler
+
+
+def _warn(message: str) -> None:
+    if _log.hasHandlers() and _log.getEffectiveLevel() <= 30:
+        _log.warning(message)
+    else:
+        warnings.warn(message)
